==> mobGameSDK-2.4.9.a-sources.jar: com/mobgame/utils/DeviceUtils.java <==
package com.mobgame.utils;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.graphics.Point;
import android.os.Build;
import android.provider.Settings.Secure;
import android.telephony.TelephonyManager;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.Display;
import android.view.KeyCharacterMap;
import android.view.KeyEvent;
import android.view.ViewConfiguration;
import android.view.WindowManager;

import com.mobgame.utils.AdvertisingIdClient.AdInfo;

import java.lang.reflect.InvocationTargetException;
import java.util.Locale;

public final class DeviceUtils {

	private static final String TAG = DeviceUtils.class.getSimpleName();
	
	public static float getDensity(Context context) {
		return context.getResources().getDisplayMetrics().density;
	}

	public static int getScreenWidthInPixels(Context context) {
		return context.getResources().getDisplayMetrics().widthPixels;
	}

	public static int getScreenHeightInPixels(Context context) {
		return context.getResources().getDisplayMetrics().heightPixels;
	}
	
	@SuppressLint("NewApi")
	public static int getRealScreenWidthInPixels(Context context) {
		WindowManager windowManager = (WindowManager) context.getSystemService(Context.WINDOW_SERVICE);
	    Display display = windowManager.getDefaultDisplay();
	    Point size = new Point();

	    if (Build.VERSION.SDK_INT >= 17) {
	        display.getRealSize(size);
	    } else if (Build.VERSION.SDK_INT >= 14) {
	        try {
	            size.x = (Integer) Display.class.getMethod("getRawWidth").invoke(display);
	            size.y = (Integer) Display.class.getMethod("getRawHeight").invoke(display);
	        } catch (IllegalAccessException e) {} catch (InvocationTargetException e) {} catch (NoSuchMethodException e) {}
	    }

	    return size.x;
	}

	@SuppressLint("NewApi")
	public static int getRealScreenHeightInPixels(Context context) {
		WindowManager windowManager = (WindowManager) context.getSystemService(Context.WINDOW_SERVICE);
	    Display display = windowManager.getDefaultDisplay();
	    Point size = new Point();

	    if (Build.VERSION.SDK_INT >= 17) {
	        display.getRealSize(size);
	    } else if (Build.VERSION.SDK_INT >= 14) {
	        try {
	            size.x = (Integer) Display.class.getMethod("getRawWidth").invoke(display);
	            size.y = (Integer) Display.class.getMethod("getRawHeight").invoke(display);
	        } catch (IllegalAccessException e) {} catch (InvocationTargetException e) {} catch (NoSuchMethodException e) {}
	    }

	    return size.y;
	}

	public static int getStatusBarHeightInPixels(Context context) {
		Resources resources = context.getResources();
		int resourceId = resources.getIdentifier("status_bar_height", "dimen", "android");
		if (resourceId > 0) {
			return resources.getDimensionPixelSize(resourceId);
		}
		return 0;
	}

	public static int getNavigationBarHeightInPixels(Context context) {
		return getRealScreenHeightInPixels(context)
			- getScreenHeightInPixels(context);
//		if (!isNavigationBarAvailable(context)) return 0;
//		Resources resources = context.getResources();
//		int orientation = context.getResources().getConfiguration().orientation;
//		int id = resources.getIdentifier(
//				orientation == Configuration.ORIENTATION_PORTRAIT
//					? "navigation_bar_height"
//					: "navigation_bar_height_landscape", 
//				"dimen", "android");
//		if (id > 0) {
//			return resources.getDimensionPixelSize(id);
//		}
//		return 0;
	}

	public static int getScreenOrientation(Context context) {
		// Query what the orientation currently really is.
		if (context.getResources().getConfiguration().orientation == Configuration.ORIENTATION_PORTRAIT) {
			return 1; // Portrait Mode

		} else if (context.getResources().getConfiguration().orientation == Configuration.ORIENTATION_LANDSCAPE) {
			return 2; // Landscape mode
		}
		return 0;
	}
	
	@SuppressLint("NewApi") 
	public static boolean isNavigationBarOnBottom(Context context) {
		Resources res = context.getResources();
		Configuration cfg = res.getConfiguration();
		DisplayMetrics dm = res.getDisplayMetrics();
		boolean canMove = (dm.widthPixels != dm.heightPixels && cfg.smallestScreenWidthDp < 600);

		return (!canMove || dm.widthPixels < dm.heightPixels);
	}

	@SuppressLint("NewApi") 
	public static boolean isNavigationBarAvailable(Context context) {
		try {
			return ViewConfiguration.get(context).hasPermanentMenuKey();
		} catch (Exception e) {
			boolean hasBackKey = KeyCharacterMap.deviceHasKey(KeyEvent.KEYCODE_BACK);
			boolean hasHomeKey = KeyCharacterMap.deviceHasKey(KeyEvent.KEYCODE_HOME);
			return (!(hasBackKey && hasHomeKey));
		}
	}

	public static String getResolution(Context c) {
		try {
			DisplayMetrics displayMetrics = new DisplayMetrics();
			((WindowManager) c.getSystemService(Context.WINDOW_SERVICE)).getDefaultDisplay().getMetrics(displayMetrics);
			String wh = displayMetrics.widthPixels + "x" + displayMetrics.heightPixels;
			
			/*
			 * IOS wh = "1136x300"; wh = "960x250"; wh = "1536x650"; wh =
			 * "2048x500"; wh = "768x325"; wh = "1024x250"; wh = "1334x350";
			 * wh = "750x530"; wh = "1920x520"; wh = "1080x750";
			 */

			/* Android */
			// Phone
			// wh = "320x480";
			// wh = "480x800";
			// wh = "480x854";
			// wh = "540x960";
			// wh = "1280x720";
			// wh = "1920x1080";
			// tablet
			// wh = "1280x800";
			// wh = "1024x600";
			
			return wh;
		} catch (Exception e) {
			return null;
		}
	}

	public static String getOSInfo() {
		return Build.MANUFACTURER + " " + Build.PRODUCT + " " + Build.VERSION.RELEASE + " " + Build.VERSION.SDK_INT;
	}

	public static String getDevice() {
		String deviceModel = ""+Build.MODEL;
		deviceModel = Utils.removeAccent(deviceModel);
		return deviceModel;
	}

	public static String getDeviceID(Context c) {
		try {
			TelephonyManager telephonyManager = (TelephonyManager) c.getSystemService(Context.TELEPHONY_SERVICE);
			String deviceId = null;
			int phoneType = telephonyManager.getPhoneType();
			Log.i("getDeviceID", "--phoneType:" + phoneType);
			switch (phoneType) {
				case TelephonyManager.PHONE_TYPE_NONE:
				case TelephonyManager.PHONE_TYPE_SIP:
				case TelephonyManager.PHONE_TYPE_CDMA:
					deviceId = telephonyManager.getDeviceId();
					break;
				case TelephonyManager.PHONE_TYPE_GSM:
					deviceId = telephonyManager.getSubscriberId();
					break;
				default:
					deviceId = null;
			}
			return deviceId;
		} catch (Exception e) {
			return null;
		}
	}

	public static String getAndroidID(Context c) {
		return Secure.getString(c.getContentResolver(), Secure.ANDROID_ID);
	}

	public static String getUniqueDeviceID(Context c) {
		String id = getAndroidID(c);
		if (TextUtils.isEmpty(id)) {
			id = getDeviceID(c);
		}
		Log.i(TAG, "getUniqueDeviceID: " + id);
		return Utils.getSHACheckSum(id);
	}
	
	private static String tmpAdvertisingID;
	public static String getAdvertisingID(final Context context) {

		if (TextUtils.isEmpty(tmpAdvertisingID)) {
			try {
				AdInfo adInfo = AdvertisingIdClient.getAdvertisingIdInfo(context);
				String adId = adInfo.getId();
				Log.i("Google Advertising id:", "Advertising ID :" + adId);
				tmpAdvertisingID = adId;
				Preference.save(context, "advertisingId", adId);
			} catch (Exception e) {
				e.printStackTrace();
			}
			return ""+tmpAdvertisingID;
		} else {
			return ""+tmpAdvertisingID;
		}
	}

	public static String getLanguage() {
		Log.e(TAG, "language" + Locale.getDefault().getLanguage());
		return Locale.getDefault().getLanguage();

	}

	public static boolean isAppInstalled(Activity activity, String packageName) {
		PackageManager pm = activity.getPackageManager();
		boolean installed = false;
		try {
			pm.getPackageInfo(packageName, PackageManager.GET_ACTIVITIES);
			installed = true;
		} catch (PackageManager.NameNotFoundException e) {
			installed = false;
		}
		return installed;
	}
}

==> mobGameSDK-4.2.3-sources.jar: com/mobgame/utils/DeviceUtils.java <==
package com.mobgame.utils;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.graphics.Point;
import android.os.Build;
import android.provider.Settings.Secure;
import android.telephony.TelephonyManager;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.Display;
import android.view.KeyCharacterMap;
import android.view.KeyEvent;
import android.view.ViewConfiguration;
import android.view.WindowManager;

import com.appsflyer.AppsFlyerLib;
import com.mobgame.utils.AdvertisingIdClient.AdInfo;

import java.lang.reflect.InvocationTargetException;
import java.util.Locale;
import java.util.UUID;

public final class DeviceUtils {

	private static final String TAG = DeviceUtils.class.getSimpleName();

	public static boolean isTablet(Context context) {
		try {
			boolean xlarge = ((context.getResources().getConfiguration().screenLayout & Configuration.SCREENLAYOUT_SIZE_MASK) == 4);
			boolean large = ((context.getResources().getConfiguration().screenLayout & Configuration.SCREENLAYOUT_SIZE_MASK) == Configuration.SCREENLAYOUT_SIZE_LARGE);
			return (xlarge || large);
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}
	}
	public static boolean hasHardwareButtons(){
		try {
			boolean hasBackKey = KeyCharacterMap.deviceHasKey(KeyEvent.KEYCODE_BACK);
			boolean hasHomeKey = KeyCharacterMap.deviceHasKey(KeyEvent.KEYCODE_HOME);
			boolean hasHardwareButtons = hasBackKey && hasHomeKey;
			Log.d(TAG , "hasHardwareButtons:" + hasHardwareButtons + " , hasBackKey: " + hasBackKey + " , "+ hasHomeKey);
			return hasHardwareButtons;
		}catch (Exception e){
			e.printStackTrace();
			return true;
		}
	}
	public static float getDensity(Context context) {
		return context.getResources().getDisplayMetrics().density;
	}

	public static int getScreenWidthInPixels(Context context) {
		return context.getResources().getDisplayMetrics().widthPixels;
	}

	public static int getScreenHeightInPixels(Context context) {
		return context.getResources().getDisplayMetrics().heightPixels;
	}
	
	@SuppressLint("NewApi")
	public static int getRealScreenWidthInPixels(Context context) {
		WindowManager windowManager = (WindowManager) context.getSystemService(Context.WINDOW_SERVICE);
	    Display display = windowManager.getDefaultDisplay();
	    Point size = new Point();

	    if (Build.VERSION.SDK_INT >= 17) {
	        display.getRealSize(size);
	    } else if (Build.VERSION.SDK_INT >= 14) {
	        try {
	            size.x = (Integer) Display.class.getMethod("getRawWidth").invoke(display);
	            size.y = (Integer) Display.class.getMethod("getRawHeight").invoke(display);
	        } catch (IllegalAccessException e) {} catch (InvocationTargetException e) {} catch (NoSuchMethodException e) {}
	    }

	    return size.x;
	}


	public static boolean isAppInstalled(Activity activity, String packageName) {
		PackageManager pm = activity.getPackageManager();
		boolean installed = false;
		try {
			pm.getPackageInfo(packageName, PackageManager.GET_ACTIVITIES);
			installed = true;
		} catch (PackageManager.NameNotFoundException e) {
			installed = false;
		}
		return installed;
	}

	@SuppressLint("NewApi")
	public static int getRealScreenHeightInPixels(Context context) {
		WindowManager windowManager = (WindowManager) context.getSystemService(Context.WINDOW_SERVICE);
	    Display display = windowManager.getDefaultDisplay();
	    Point size = new Point();

	    if (Build.VERSION.SDK_INT >= 17) {
	        display.getRealSize(size);
	    } else if (Build.VERSION.SDK_INT >= 14) {
	        try {
	            size.x = (Integer) Display.class.getMethod("getRawWidth").invoke(display);
	            size.y = (Integer) Display.class.getMethod("getRawHeight").invoke(display);
	        } catch (IllegalAccessException e) {} catch (InvocationTargetException e) {} catch (NoSuchMethodException e) {}
	    }

	    return size.y;
	}

	public static int getStatusBarHeightInPixels(Context context) {
		Resources resources = context.getResources();
		int resourceId = resources.getIdentifier("status_bar_height", "dimen", "android");
		if (resourceId > 0) {
			return resources.getDimensionPixelSize(resourceId);
		}
		return 0;
	}

	public static int getNavigationBarHeightInPixels(Context context) {
		return getRealScreenHeightInPixels(context)
			- getScreenHeightInPixels(context);
	}

	public static int getScreenOrientation(Context context) {
		// Query what the orientation currently really is.
		try {
			if (context.getResources().getConfiguration().orientation == Configuration.ORIENTATION_PORTRAIT) {
				return 1; // Portrait Mode

			} else if (context.getResources().getConfiguration().orientation == Configuration.ORIENTATION_LANDSCAPE) {
				return 2; // Landscape mode
			}
		} catch (Exception e){
			e.printStackTrace();
		}
		return 0;
	}
	
	@SuppressLint("NewApi") 
	public static boolean isNavigationBarOnBottom(Context context) {
		Resources res = context.getResources();
		Configuration cfg = res.getConfiguration();
		DisplayMetrics dm = res.getDisplayMetrics();
		boolean canMove = (dm.widthPixels != dm.heightPixels && cfg.smallestScreenWidthDp < 600);

		return (!canMove || dm.widthPixels < dm.heightPixels);
	}

	public static String getResolution(Context c) {
		try {
			DisplayMetrics displayMetrics = new DisplayMetrics();
			((WindowManager) c.getSystemService(Context.WINDOW_SERVICE)).getDefaultDisplay().getMetrics(displayMetrics);
			String wh = displayMetrics.widthPixels + "x" + displayMetrics.heightPixels;
			
			/*
			 * IOS wh = "1136x300"; wh = "960x250"; wh = "1536x650"; wh =
			 * "2048x500"; wh = "768x325"; wh = "1024x250"; wh = "1334x350";
			 * wh = "750x530"; wh = "1920x520"; wh = "1080x750";
			 */

			/* Android */
			// Phone
			// wh = "320x480";
			// wh = "480x800";
			// wh = "480x854";
			// wh = "540x960";
			// wh = "1280x720";
			// wh = "1920x1080";
			// tablet
			// wh = "1280x800";
			// wh = "1024x600";
			
			return wh!=null ? wh:"";
		} catch (Exception e) {
			Log.d("getResolution",e.getMessage());
			return "";
		}
	}

	public static String getOSInfo() {
		return (Build.MANUFACTURER != null ? Build.MANUFACTURER : "") + " " + (Build.PRODUCT != null ? Build.PRODUCT : "") + " " + (Build.VERSION.RELEASE != null ? Build.VERSION.RELEASE : "") + " " + Build.VERSION.SDK_INT;
	}

	public static String getDevice() {
//		return "";
		return Build.MODEL !=null ?Build.MODEL :"";
//		return null;
	}

	private static String uniqueID = null;
	private static final String PREF_UNIQUE_ID = "PREF_UNIQUE_ID";
	public synchronized static String getUniqueID(Context context) {
		if (uniqueID == null) {
			uniqueID = Preference.getString(context, PREF_UNIQUE_ID);
			if (uniqueID == null) {
				uniqueID = UUID.randomUUID().toString();
				Preference.save(context , PREF_UNIQUE_ID , uniqueID);
			}
		}
		return uniqueID;
	}

	public static String getAndroidID(Context c) {
		return Secure.getString(c.getContentResolver(), Secure.ANDROID_ID);
	}

	public static String getUniqueDeviceID(Context c) {
		String id = getAndroidID(c);
		if (TextUtils.isEmpty(id)) {
			id = getUniqueID(c);
		}
		Log.i(TAG, "getUniqueDeviceID: " + id);
		return Utils.getSHACheckSum(id);
	}

	public static String getAppsflyerUID(final Context context){
		try {
			String appslyerId = AppsFlyerLib.getInstance().getAppsFlyerUID(context);
			return appslyerId !=null ? appslyerId:"";
		}catch (Exception e){
			e.printStackTrace();
			return "";
		}
	}
	private static String tmpAdvertisingID;
	public static String getAdvertisingID(final Context context) {
		try {
			if (TextUtils.isEmpty(tmpAdvertisingID)) {
				try {
					AdInfo adInfo = AdvertisingIdClient.getAdvertisingIdInfo(context);
					String adId = adInfo.getId();
					Log.i("Google Advertising id:", "Advertising ID :" + adId);
					tmpAdvertisingID = adId;
					Preference.save(context, "advertisingId", adId);
				} catch (Exception e) {
					e.printStackTrace();
				}
				return ""+tmpAdvertisingID;
			} else {
				return ""+tmpAdvertisingID;
			}
		}catch (Exception e){
			e.printStackTrace();
			return "";
		}

	}

	private static String language = "en";
	public static void setLanguage(String lang){
		language = lang;
	}
	public static String getLanguage() {
		Log.e(TAG, "language" + Locale.getDefault().getLanguage());
		language = Locale.getDefault().getDisplayLanguage();
		if(language.equals("vi")){
			return "vie";
		}else if(language.equals("zh")){
			return "zh-Hans";
		}else if(language.equals("en")){
			return "en";
		}else{
			return "vie";
		}
	}
}
